@@ -1,7 +1,7 @@
 package Bencher;
 
-our $DATE = '2015-12-09'; # DATE
-our $VERSION = '0.17'; # VERSION
+our $DATE = '2015-12-17'; # DATE
+our $VERSION = '0.18'; # VERSION
 
 use 5.010001;
 use strict;
@@ -930,6 +930,16 @@ _
             },
             tags => ['category:action'],
         },
+        raw => {
+            summary => 'Show "raw" data',
+            schema => 'bool',
+            description => <<'_',
+
+When action=show-items-result, will print result as-is instead of dumping as
+Perl.
+
+_
+        },
         module_startup => {
             schema => ['bool*', is=>1],
             summary => 'Benchmark module startup overhead instead of normal benchmark',
@@ -1364,6 +1374,15 @@ sub bencher {
         if ($action eq 'show-items-results') {
             if ($return_resmeta) {
                 $envres->[2] = [map {$_->{_result}} @$items];
+            } elsif ($args{raw}) {
+                $envres->[2] = join(
+                    "",
+                    map {(
+                        "#$_->{seq} ($_->{name}):\n",
+                        $_->{_result},
+                        "\n\n",
+                    )} @$items
+                );
             } else {
                 require Data::Dump;
                 $envres->[2] = join(
@@ -1545,7 +1564,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 0.17 of Bencher (from Perl distribution Bencher), released on 2015-12-09.
+This document describes version 0.18 of Bencher (from Perl distribution Bencher), released on 2015-12-17.
 
 =head1 SYNOPSIS
 
@@ -1718,6 +1737,13 @@ will "skip" the item.
 
 Add participants.
 
+=item * B<raw> => I<bool>
+
+Show "raw" data.
+
+When action=show-items-result, will print result as-is instead of dumping as
+Perl.
+
 =item * B<scenario_file> => I<str>
 
 Load a scenario from a Perl file.
